import asyncio
from logging import error
import unittest
import sys
from os import path
sys.path.append( path.dirname( path.dirname( path.abspath(__file__) ) ) )

from foxrestapiclient.connection.rest_api_client import RestApiClient
from foxrestapiclient.connection.rest_api_responses import RestApiBaseResponse, RestApiDeviceStateResponse
from foxrestapiclient.connection.const import (
    API_RESPONSE_STATUS_FAIL,
    API_RESPONSE_STATUS_OK,
    API_COMMON_DEVICE_OFF,
    API_COMMON_DEVICE_ON
)
from .const import (
    API_KEY,
    CHANNELS,
    HOST,
    NAME,
    TYPE,
    UNIQUE_ID
)
def async_test(coro):
    def wrapper(*args, **kwargs):
        loop = asyncio.new_event_loop()
        try:
            return loop.run_until_complete(coro(*args, **kwargs))
        finally:
            loop.close()
    return wrapper

class RestApiClientTest(unittest.TestCase):
    restApiClient = RestApiClient(HOST, API_KEY)
    status_dic = [API_RESPONSE_STATUS_OK, API_RESPONSE_STATUS_FAIL]

    def test_get_base_api_url(self):
        """Test base url contatentation"""
        self.assertEqual(self.restApiClient.get_base_api_url(),
            "http://{0}/{1}/".format(HOST, API_KEY))

    def test_get_device_non_responding_response(self):
        self.assertEqual(self.restApiClient.get_device_non_responding_response().status,
            RestApiBaseResponse("false").status)

    @async_test
    async def test_async_api_get_device_state(self):
        dev_state: RestApiDeviceStateResponse = await self.restApiClient.async_api_get_device_state()
        #Device should be enabled and accessed via host and api_key to pass this test!!!
        self.assertIn(dev_state.status, self.status_dic)
        if dev_state.state is not None:
            self.assertIn(dev_state.state, [API_COMMON_DEVICE_ON, API_COMMON_DEVICE_OFF])
            return
        if dev_state.channel_1_state is not None and dev_state.channel_2_state is not None:
            self.assertIn(dev_state.channel_1_state, [API_COMMON_DEVICE_ON, API_COMMON_DEVICE_OFF])
            self.assertIn(dev_state.channel_2_state, [API_COMMON_DEVICE_ON, API_COMMON_DEVICE_OFF])
            return

        self.assertFalse("Unexcepted behaviour")

    @async_test
    async def test_async_api_get_device_info(self):
        dev_info = await self.restApiClient.async_api_get_device_info()
        self.assertIn(dev_info.status, self.status_dic)
        if dev_info.status == API_RESPONSE_STATUS_FAIL:
            self.assertIsNotNone(dev_info.error)

    @async_test
    async def test_async_make_api_call_get(self):
        await self.restApiClient.async_make_api_call_get("hh")

if __name__ == '__main__':
    unittest.main()


import asyncio
from logging import error
import unittest
import sys
from os import path, wait
sys.path.append( path.dirname( path.dirname( path.abspath(__file__) ) ) )
from foxrestapiclient.devices.fox_rgbw_device import DeviceData, FoxRGBWDevice
from .const import (
    API_KEY,
    CHANNELS,
    HOST,
    NAME,
    TYPE,
    UNIQUE_ID
)

def async_test(coro):
    def wrapper(*args, **kwargs):
        loop = asyncio.new_event_loop()
        try:
            return loop.run_until_complete(coro(*args, **kwargs))
        finally:
            loop.close()
    return wrapper


class RGBWDeviceTest(unittest.TestCase):
    device = FoxRGBWDevice(
        DeviceData(NAME, HOST, API_KEY, UNIQUE_ID, TYPE, CHANNELS)
        )

    @async_test
    async def test_async_color_hsv(self):
        await self.device.async_set_color_hsv(100,80,70)
        await asyncio.sleep(5)
        hsv = await self.device.async_fetch_color_hsv()
        self.assertEqual(hsv[0], 100)
        self.assertEqual(hsv[1], 80)
        self.assertEqual(hsv[2], 68)

    @async_test
    async def test_async_set_brightness(self):
        await self.device.async_set_brightness(0)

if __name__ == '__main__':
    unittest.main()


import asyncio
from logging import error
import unittest
import sys
from os import path
sys.path.append( path.dirname( path.dirname( path.abspath(__file__) ) ) )

from foxrestapiclient.devices.fox_r2s2_device import DeviceData, FoxR2S2Device
from .const import (
    API_KEY,
    CHANNELS,
    HOST,
    NAME,
    TYPE,
    UNIQUE_ID
)

def async_test(coro):
    def wrapper(*args, **kwargs):
        loop = asyncio.new_event_loop()
        try:
            return loop.run_until_complete(coro(*args, **kwargs))
        finally:
            loop.close()
    return wrapper

class R2S2DeviceTest(unittest.TestCase):
    device = FoxR2S2Device(
        DeviceData(NAME, HOST, API_KEY, UNIQUE_ID, TYPE, CHANNELS)
        )

    @async_test
    async def test_async_fetch_update(self):

        try:
            await self.device.async_fetch_update()
        except:
            self.assertFalse(True)
        self.assertTrue(True)

    def test_is_on(self):
        self.assertIn(self.device.is_on(2), [True, False])

if __name__ == '__main__':
    unittest.main()


import asyncio
from logging import error
import unittest
import sys
from os import path
sys.path.append( path.dirname( path.dirname( path.abspath(__file__) ) ) )

from foxrestapiclient.devices.fox_base_device import FoxBaseDevice, UnsupportedDevice
from .const import (
    API_KEY,
    CHANNELS,
    HOST,
    NAME,
    TYPE,
    UNIQUE_ID
)
def async_test(coro):
    def wrapper(*args, **kwargs):
        loop = asyncio.new_event_loop()
        try:
            return loop.run_until_complete(coro(*args, **kwargs))
        finally:
            loop.close()
    return wrapper

class FoxBaseDeviceTest(unittest.TestCase):
    def test_init_base_device(self):
        try:
            FoxBaseDevice(NAME, HOST, API_KEY, UNIQUE_ID, TYPE)
        except UnsupportedDevice:
            self.assertFalse(True)
        self.assertFalse(False)

    def test_equals(self):
        self.assertEqual(FoxBaseDevice(NAME, HOST, API_KEY, UNIQUE_ID, TYPE).equals(
            FoxBaseDevice(NAME, HOST, API_KEY, UNIQUE_ID, TYPE)), True)

    def test_get_device_info(self):
        info = FoxBaseDevice(NAME, HOST, API_KEY, UNIQUE_ID, TYPE).get_device_info()
        if info != "":
            self.assertTrue(True)
        else:
            self.assertTrue(False)

    @async_test
    async def test_async_fetch_device_available_data(self):
        """If device is not available this test will be pass"""
        dev = FoxBaseDevice(NAME, HOST, API_KEY, UNIQUE_ID, TYPE)
        await dev.async_fetch_device_available_data()

if __name__ == '__main__':
    unittest.main()


import asyncio
from logging import error
import unittest
import sys
from os import path, wait
sys.path.append( path.dirname( path.dirname( path.abspath(__file__) ) ) )
from foxrestapiclient.devices.fox_service_discovery import FoxServiceDiscovery

def async_test(coro):
    def wrapper(*args, **kwargs):
        loop = asyncio.new_event_loop()
        try:
            return loop.run_until_complete(coro(*args, **kwargs))
        finally:
            loop.close()
    return wrapper

class ServiceDiscoveryTest(unittest.TestCase):

    @async_test
    async def test(self):
        discovered = await FoxServiceDiscovery().async_discover_devices()
        if len(discovered) == 0:
            self.assertFalse(True)
        for device in discovered:
            self.assertIsNotNone(device.name)

if __name__ == '__main__':
    unittest.main()


import asyncio
from logging import error
import unittest
import sys
from os import path, wait
sys.path.append( path.dirname( path.dirname( path.abspath(__file__) ) ) )
from foxrestapiclient.devices.fox_dimmable_device import DeviceData, FoxDimmableDevice
from .const import (
    API_KEY,
    CHANNELS,
    HOST,
    NAME,
    TYPE,
    UNIQUE_ID
)

def async_test(coro):
    def wrapper(*args, **kwargs):
        loop = asyncio.new_event_loop()
        try:
            return loop.run_until_complete(coro(*args, **kwargs))
        finally:
            loop.close()
    return wrapper

class DimmableDeviceTest(unittest.TestCase):
    device = FoxDimmableDevice(
        DeviceData(NAME, HOST, API_KEY, UNIQUE_ID, TYPE, CHANNELS)
        )

    @async_test
    async def test_turn_off(self):
        await self.device.async_update_channel_state(False, 1)
        await self.device.async_update_channel_state(False, 2)
        await self.device.async_fetch_update()
        await asyncio.sleep(1)

    @async_test
    async def test_turn_on(self):
        await self.device.async_update_channel_state(True, 1)
        await self.device.async_update_channel_state(True, 2)
        await self.device.async_fetch_update()
        await asyncio.sleep(1)

    @async_test
    async def test_async_update_channel_brightness(self):
        await self.device.async_update_channel_brightness(10, 1)
        await self.device.async_update_channel_brightness(10, 2)

if __name__ == '__main__':
    unittest.main()